@@ -15,10 +15,10 @@ fn impl_dyn_partial_eq(ast: &syn::DeriveInput) -> TokenStream {
   let name = &ast.ident;
   let gen = quote! {
       impl DynPartialEq for #name {
-          fn as_any(&self) -> &dyn std::any::Any {
+          fn as_any(&self) -> &dyn core::any::Any {
             self
           }
-          fn box_eq(&self, other: &dyn std::any::Any) -> bool {
+          fn box_eq(&self, other: &dyn core::any::Any) -> bool {
             other.downcast_ref::<Self>().map_or(false, |a| self == a)
           }
       }
@@ -43,7 +43,13 @@ pub fn dyn_partial_eq(_: TokenStream, input: TokenStream) -> TokenStream {
     #input
 
     impl core::cmp::PartialEq for Box<dyn #name> {
-      fn eq(&self, other: &Box<dyn #name>) -> bool {
+      fn eq(&self, other: &Self) -> bool {
+        self.box_eq(other.as_any())
+      }
+    }
+
+    impl core::cmp::PartialEq<&Self> for Box<dyn #name> {
+      fn eq(&self, other: &&Self) -> bool {
         self.box_eq(other.as_any())
       }
     }
